@@ -7,7 +7,7 @@ from typing import Any
 from aiohttp import ClientResponse, ClientSession
 
 from .exceptions import AuthenticationError, SensiboError
-from .model import MotionSensor, SensiboData, SensiboDevice
+from .model import MotionSensor, Schedules, SensiboData, SensiboDevice
 
 APIV1 = "https://home.sensibo.com/api/v1"
 APIV2 = "https://home.sensibo.com/api/v2"
@@ -49,17 +49,19 @@ class SensiboClient:
         """Return dataclass with Sensibo Devices."""
         devices = []
         data = await self.async_get_devices()
-        for dev in data["result"]:
-            devices.append(dev)
+        for device in data["result"]:
+            devices.append(device)
 
         device_data: dict[str, SensiboDevice] = {}
+        dev: dict
         for dev in devices:
             unique_id = dev["id"]
             mac = dev["macAddress"]
             name = dev["room"]["name"]
-            temperature = dev["measurements"].get("temperature")
-            humidity = dev["measurements"].get("humidity")
-            ac_states = dev["acState"]
+            measure: dict = dev["measurements"]
+            temperature = measure.get("temperature")
+            humidity = measure.get("humidity")
+            ac_states: dict = dev["acState"]
             target_temperature = ac_states.get("targetTemperature")
             hvac_mode = ac_states.get("mode")
             running = ac_states.get("on")
@@ -72,7 +74,7 @@ class SensiboClient:
             hvac_modes = list(capabilities["modes"])
             if hvac_modes:
                 hvac_modes.append("off")
-            current_capabilities = capabilities["modes"][ac_states.get("mode")]
+            current_capabilities: dict = capabilities["modes"][ac_states.get("mode")]
             fan_modes = current_capabilities.get("fanLevels")
             swing_modes = current_capabilities.get("swing")
             horizontal_swing_modes = current_capabilities.get("horizontalSwing")
@@ -113,8 +115,9 @@ class SensiboClient:
             fw_type = dev["firmwareType"]
             model = dev["productModel"]
 
-            calibration_temp = dev["sensorsCalibration"].get("temperature")
-            calibration_hum = dev["sensorsCalibration"].get("humidity")
+            calibration: dict = dev["sensorsCalibration"]
+            calibration_temp = calibration.get("temperature")
+            calibration_hum = calibration.get("humidity")
 
             # Sky plus supports functionality to use motion sensor as sensor for temp and humidity
             if main_sensor := dev["mainMeasurementsSensor"]:
@@ -124,11 +127,13 @@ class SensiboClient:
 
             motion_sensors: dict[str, MotionSensor] = {}
             if dev["motionSensors"]:
+                sensor: dict
                 for sensor in dev["motionSensors"]:
-                    measurement = sensor["measurements"]
+                    measurement: dict = sensor["measurements"]
+                    connection: dict = sensor["connectionStatus"]
                     motion_sensors[sensor["id"]] = MotionSensor(
                         id=sensor["id"],
-                        alive=sensor["connectionStatus"].get("isAlive"),
+                        alive=connection.get("isAlive"),
                         motion=measurement.get("motion"),
                         fw_ver=sensor.get("firmwareVersion"),
                         fw_type=sensor.get("firmwareType"),
@@ -141,10 +146,21 @@ class SensiboClient:
                     )
 
             # Add information for pure devices
-            pure_conf = dev["pureBoostConfig"]
-            pure_sensitivity = pure_conf.get("sensitivity") if pure_conf else None
-            pure_boost_enabled = pure_conf.get("enabled") if pure_conf else None
-            pm25 = dev["measurements"].get("pm25")
+            pure_conf: dict = dev["pureBoostConfig"] if dev["pureBoostConfig"] else {}
+            pure_boost_enabled = None
+            pure_sensitivity = None
+            pure_ac_integration = None
+            pure_geo_integration = None
+            pure_measure_integration = None
+            if dev["productModel"] == "pure":
+                pure_boost_enabled = pure_conf.get("enabled", False)
+                pure_sensitivity = pure_conf.get("sensitivity", "off")
+                pure_ac_integration = pure_conf.get("ac_integration", False)
+                pure_geo_integration = pure_conf.get("geo_integration", False)
+                pure_measure_integration = pure_conf.get(
+                    "measurements_integration", False
+                )
+            pm25 = measure.get("pm25")
 
             # Binary sensors for main device
             room_occupied = dev["roomIsOccupied"]
@@ -152,6 +168,51 @@ class SensiboClient:
                 dev["firmwareVersion"] != dev["currentlyAvailableFirmwareVersion"]
             )
 
+            # Filters
+            filters: dict = dev["filtersCleaning"] if dev["filtersCleaning"] else {}
+            filter_clean = filters.get("shouldCleanFilters", False)
+            clean_time: dict = filters.get("lastFiltersCleanTime") or {}
+            filter_last_reset = clean_time.get("time") if clean_time else None
+
+            # Timer
+            timer: dict = dev["timer"] if dev["timer"] else {}
+            timer_on = None
+            timer_id = None
+            timer_state_on = None
+            timer_time = None
+            if dev["productModel"] != "pure":
+                timer_on = timer.get("isEnabled", False)
+            timer_id = timer.get("id")
+            timer_state: dict | None = timer.get("acState")
+            timer_state_on = timer_state.get("on") if timer_state else None
+            timer_time = timer.get("targetTime")
+
+            # Smartmode
+            smart: dict = dev["smartMode"] if dev["smartMode"] else {}
+            smart_on = None
+            if dev["productModel"] != "pure":
+                smart_on = smart.get("enabled", False)
+            smart_type = smart.get("type")
+            smart_low_temp_threshold = smart.get("lowTemperatureThreshold")
+            smart_high_temp_threshold = smart.get("highTemperatureThreshold")
+            smart_low_state = smart.get("lowTemperatureState")
+            smart_high_state = smart.get("highTemperatureState")
+
+            # Schedules
+            schedule_list = dev["schedules"]
+            schedules: dict[str, Schedules] = {}
+            if schedule_list:
+                for schedule in schedule_list:
+                    schedules[schedule["id"]] = Schedules(
+                        id=schedule["id"],
+                        enabled=schedule["isEnabled"],
+                        state_on=schedule["acState"].get("on"),
+                        state_full=schedule["acState"],
+                        days=schedule["recurringDays"],
+                        time=schedule["targetTimeLocal"],
+                        next_utc=schedule["nextTime"],
+                    )
+
             device_data[unique_id] = SensiboDevice(
                 id=unique_id,
                 mac=mac,
@@ -186,11 +247,27 @@ class SensiboClient:
                 calibration_hum=calibration_hum,
                 full_capabilities=capabilities,
                 motion_sensors=motion_sensors,
-                pure_sensitivity=pure_sensitivity,
                 pure_boost_enabled=pure_boost_enabled,
+                pure_sensitivity=pure_sensitivity,
+                pure_ac_integration=pure_ac_integration,
+                pure_geo_integration=pure_geo_integration,
+                pure_measure_integration=pure_measure_integration,
                 pm25=pm25,
                 room_occupied=room_occupied,
                 update_available=update_available,
+                filter_clean=filter_clean,
+                filter_last_reset=filter_last_reset,
+                timer_on=timer_on,
+                timer_id=timer_id,
+                timer_state_on=timer_state_on,
+                timer_time=timer_time,
+                smart_on=smart_on,
+                smart_type=smart_type,
+                smart_low_temp_threshold=smart_low_temp_threshold,
+                smart_high_temp_threshold=smart_high_temp_threshold,
+                smart_low_state=smart_low_state,
+                smart_high_state=smart_high_state,
+                schedules=schedules,
             )
 
         return SensiboData(raw=data, parsed=device_data)
@@ -204,6 +281,16 @@ class SensiboClient:
         params = {"apiKey": self.api_key, "fields": fields}
         return await self._get(APIV2 + "/pods/{}".format(uid), params)
 
+    async def async_reset_filter(self, uid: str) -> dict[str, Any]:
+        """Reset filters.
+
+        uid: UID for device
+        """
+        params = {"apiKey": self.api_key}
+        return await self._delete(
+            APIV2 + "/pods/{}/cleanFiltersNotification".format(uid), params
+        )
+
     async def async_get_climate_react(self, uid: str) -> dict[str, Any]:
         """Get Climate React on a device.
 
@@ -223,6 +310,17 @@ class SensiboClient:
         params = {"apiKey": self.api_key}
         return await self._put(APIV2 + "/pods/{}/smartmode".format(uid), params, data)
 
+    async def async_set_climate_react(
+        self, uid: str, data: dict[str, bool]
+    ) -> dict[str, Any]:
+        """Set Climate React on a device.
+
+        uid: UID for device
+        data: dict according to dev["smartmode"]
+        """
+        params = {"apiKey": self.api_key}
+        return await self._put(APIV2 + "/pods/{}/smartmode".format(uid), params, data)
+
     async def async_get_timer(self, uid: str) -> dict[str, Any]:
         """Get Timer on a device.
 
