@@ -49,12 +49,28 @@ class SensiboDevice:
     calibration_temp: float | None
     calibration_hum: float | None
     full_capabilities: dict[str, Any]
-    motion_sensors: dict[str, MotionSensor]
-    pure_sensitivity: str | None
-    pure_boost_enabled: bool | None
+    motion_sensors: dict[str, MotionSensor] | None
     pm25: int | None
     room_occupied: bool
     update_available: bool
+    schedules: dict[str, Schedules] | None
+    pure_boost_enabled: bool | None
+    pure_sensitivity: str | None
+    pure_ac_integration: bool | None
+    pure_geo_integration: bool | None
+    pure_measure_integration: bool | None
+    timer_on: bool | None
+    timer_id: str | None
+    timer_state_on: bool | None
+    timer_time: str | None
+    smart_on: bool | None
+    smart_type: str | None
+    smart_low_temp_threshold: float | None
+    smart_high_temp_threshold: float | None
+    smart_low_state: dict | None
+    smart_high_state: dict | None
+    filter_clean: bool
+    filter_last_reset: str | None
 
 
 @dataclass
@@ -72,3 +88,16 @@ class MotionSensor:
     temperature: float | None = None
     model: str | None = None
     rssi: int | None = None
+
+
+@dataclass
+class Schedules:
+    """Dataclass for schedules."""
+
+    id: str
+    enabled: bool
+    state_on: bool | None
+    state_full: dict
+    days: list
+    time: str
+    next_utc: str
